@@ -29,7 +29,8 @@ pub fn cell_size_in_pixels() -> std::io::Result<(u32, u32)> {
         ws_xpixel: 0,
         ws_ypixel: 0,
     };
-    let r = unsafe { ioctl(STDOUT_FILENO, TIOCGWINSZ, &w) };
+    #[allow(clippy::useless_conversion)]
+    let r = unsafe { ioctl(STDOUT_FILENO, TIOCGWINSZ.into(), &w) };
     if r == 0 && w.ws_xpixel > w.ws_col && w.ws_ypixel > w.ws_row {
         Ok((
             (w.ws_xpixel / w.ws_col) as u32,
